// Copyright (c) 2007 Paul Miner <$firstname.$lastname@gmail.com>
// This software is provided 'as-is', without any express or implied warranty. In no event will the authors be held liable for any damages arising from the use of this software.
// Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:
//     1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
//     2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
//     3. This notice may not be removed or altered from any source distribution.

package org.blinkenbyte.io;

import java.io.IOException;

/**
 * A BlockDeviceFilter contains another BlockDevice which it passes all method calls to. Another class can extend this class to filter
 * particular methods.
 *
 * @see org.blinkenbyte.io.BadBlockEmulator
 */
public class BlockDeviceFilter implements BlockDevice
{
  protected BlockDevice bd = null;

  public BlockDeviceFilter(BlockDevice _bd)
  {
    bd = _bd;
  }

  public void close() throws IOException
  {
    bd.close();
    return;
  }
  
  public void open(String filename, boolean allowWrite, boolean syncWriteData, boolean syncWriteMetaData, boolean sectorMode) throws Exception
  {
    bd.open(filename, allowWrite, syncWriteData, syncWriteMetaData, sectorMode);
    return;
  }
  
  public long getFilePointer() throws IOException
  {
    return bd.getFilePointer();
  }
  
  public long length() throws IOException
  {
    return bd.length();
  }
  
  public int read() throws IOException
  {
    return bd.read();
  }
  
  public int read(byte[] b) throws IOException
  {
    return read(b, 0, b.length);
  }
  
  public int read(byte[] b, int offset, int len) throws IOException
  {
    return bd.read(b, offset, len);
  }
  
  public void seek(long pos) throws IOException
  {
    bd.seek(pos);
    return;
  }
  
  public int skipBytes(int n) throws IOException
  {
    return bd.skipBytes(n);
  }
  
  public void write(byte[] b) throws IOException
  {
    write(b, 0, b.length);
    return;
  }
  
  public void write(byte[] b, int offset, int len) throws IOException
  {
    bd.write(b, offset, len);
    return;
  }
  
  public void write(int b) throws IOException
  {
    bd.write(b);
    return;
  }
  
  public BlockDevice.DriveGeometry getDriveGeometry() throws Exception
  {
    return bd.getDriveGeometry();
  }
  
  public int getSectorSize()
  {
    return bd.getSectorSize();
  }
  
  public void setSectorSize(int sectorSize) throws Exception
  {
    bd.setSectorSize(sectorSize);
    return;
  }
  
  public int getSectorSizeLog()
  {
    return bd.getSectorSizeLog();
  }
  
  public boolean getAutoSectorAlign()
  {
    return bd.getAutoSectorAlign();
  }
  
  public void setAutoSectorAlign(boolean _autoSectorAlign)
  {
    bd.setAutoSectorAlign(_autoSectorAlign);
    return;
  }

}
